# -*- coding:utf-8 -*-
__author__ = 'bee'

from django import forms
from django.contrib.auth.models import User, Group

from .models import UserProfile, UserClass, UserLeaveRecord, USER_LEAVE_TYPE_CHOICES
from django.forms.models import inlineformset_factory


class UserForm(forms.ModelForm):
    class Meta:
        model = User
        fields = ["first_name"]


class UserSearchForm(forms.Form):
    group = forms.ModelChoiceField(queryset=Group.objects.all(), label='用户组', required=False)
    student_id = forms.CharField(label='学号', required=False)
    first_name = forms.CharField(label='用户姓名', required=False)


    # class Meta:
    #     model = User
    #     fields = ["student_id","first_name"]


class UserProfileForm(forms.ModelForm):
    class Meta:
        model = UserProfile
        fields = ['start_date', "user_class"]


profile_inline_formset = inlineformset_factory(User, UserProfile, form=UserProfileForm, can_delete=False)


class UserClassForm(forms.ModelForm):
    assistant_queryset = User.objects.filter(groups__name__in=['助教'])
    assistant = forms.ModelChoiceField(queryset=assistant_queryset, label='助教', required=False)

    class Meta:
        model = UserClass
        fields = ["name", 'assistant']


class UserGroupForm(forms.ModelForm):
    class Meta:
        model = User
        fields = ['groups']


# 请假/延期
class UserLeaveRecordForm(forms.ModelForm):
    type_choices = ((1, "请假"), (3, "延期"))
    type = forms.ChoiceField(choices=type_choices, label='类型')

    class Meta:
        model = UserLeaveRecord
        fields = ['type', "start", "end", "info"]


# 请假/延期
class UserLeaveRecordCancelForm(forms.ModelForm):
    type_choices = ((2, "销假"),)
    type = forms.ChoiceField(choices=type_choices, label='类型')

    class Meta:
        model = UserLeaveRecord
        fields = ['type', "start", "info"]



# -*- coding:utf-8 -*-
__author__ = 'bee'

import json
import unicodecsv as csv
from django.http import StreamingHttpResponse
from bee_django_user.models import UserProfile
from django.conf import settings


def get_max_student_id():
    user_profile_list = UserProfile.objects.filter(student_id__isnull=False).order_by("-student_id")
    if user_profile_list.count() >= 1:
        max_student_id = user_profile_list.first().student_id

    else:
        max_student_id = 0
    return max_student_id


def get_user():
    user_list = UserProfile.objects.all()
    user_count = user_list.count()
    female_user_list = UserProfile.get_female_user_list()
    male_user_list = UserProfile.get_male_user_list()


def test():
    from  bee_django_course.models import UserLive
    from django.db.models import Count, Sum
    UserLive.objects.filter(status__in=[1, 2], record_status='10').values("user__userprofile__preuser__city").annotate(
        sum_duration=Sum("duration"), sum_user=Sum("user")).order_by('user__userprofile__preuser__city')

    # annotate(
    #     count_city=Count("user__userprofile__preuser__city")).order_by("-count_city")



# 导出csv
def export_csv(filename, headers, rows):
    response = StreamingHttpResponse((row for row in csv_itertor(headers, rows)), content_type="text/csv;charset=utf-8")
    response['Content-Disposition'] = 'attachment;filename="' + filename + '.csv"'
    return response


def csv_itertor(headers, rows):
    pseudo_buffer = Echo()
    writer = csv.writer(pseudo_buffer)
    yield writer.writerow(headers)
    for column in rows:
        yield writer.writerow(column)


class Echo(object):
    """An object that implements just the write method of the file-like
    interface.
    """

    def write(self, value):
        """Write the value by returning it, instead of storing in a buffer."""
        return value


# 完



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-05-07 07:01
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_crm', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserClass',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=180, verbose_name='\u73ed\u7ea7\u540d\u79f0')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('assistant', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE,
                                                to=settings.AUTH_USER_MODEL, verbose_name='\u52a9\u6559')),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'bee_django_user_class',
            },
        ),
        migrations.CreateModel(
            name='UserProfile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('student_id', models.IntegerField(null=True, unique=True, verbose_name='\u5b66\u53f7')),
                ('room_id',
                 models.CharField(blank=True, max_length=180, null=True, verbose_name='\u4e60\u7434\u5ba4ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('preuser',
                 models.OneToOneField(null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.CRM_PREUSER,
                                      verbose_name='crm\u7528\u6237')),
                ('user', models.OneToOneField(null=True, on_delete=django.db.models.deletion.CASCADE,
                                              to=settings.AUTH_USER_MODEL)),
                ('user_class', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL,
                                                 to='bee_django_user.UserClass',
                                                 verbose_name='\u7528\u6237\u73ed\u7ea7')),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'bee_django_user_profile',
                'permissions': (('user.can_manage', 'can manage'), ('user.can_change', 'can change user info'),
                                ('user.can_change_group', 'can change user group'),
                                ('user.can_delete', 'can delete user'), ('user.can_create', 'can create user'),
                                ('user.view_all', 'view all users'), ('user.view_manage', 'view manage users'),
                                ('user.view_teach', 'view teach users')),
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-10-30 06:59
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0009_userleavestatus'),
    ]

    operations = [
        migrations.AddField(
            model_name='userleaverecord',
            name='info',
            field=models.TextField(blank=True, null=True, verbose_name='\u5907\u6ce8'),
        ),
        migrations.AlterField(
            model_name='userleaverecord',
            name='type',
            field=models.IntegerField(choices=[(1, '\u8bf7\u5047'), (2, '\u9500\u5047'), (3, '\u5ef6\u671f/\u63d0\u524d')], default=1, verbose_name='\u7c7b\u578b'),
        ),
    ]
